timelink.app.schemas package
============================

.. automodule:: timelink.app.schemas
   :no-undoc-members:
   :no-show-inheritance:

Submodules
----------

timelink.app.schemas.project module
-----------------------------------

.. automodule:: timelink.app.schemas.project
   :no-undoc-members:
   :no-show-inheritance:

timelink.app.schemas.user module
--------------------------------

.. automodule:: timelink.app.schemas.user
   :no-undoc-members:
   :no-show-inheritance:
